'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fontSizes = [12, 15, 17, 20, 24, 28, 34, 42, 50, 70];
var breakpoints = [740, 980, 1140, 1300]; // Diverges from https://system-ui.com
// At these widths, there are tweaks to the
// fluid grid on mobile devices

var tweakpoints = [375, 480, 660];

var breakpoints$1 = {
  mobileMedium: tweakpoints[0],
  mobileLandscape: tweakpoints[1],
  phablet: tweakpoints[2],
  tablet: breakpoints[0],
  desktop: breakpoints[1],
  leftCol: breakpoints[2],
  wide: breakpoints[3]
};

var headlineSizes = {
  1: fontSizes[2],
  2: fontSizes[3],
  3: fontSizes[4],
  4: fontSizes[5],
  5: fontSizes[6],
  6: fontSizes[7],
  7: fontSizes[8],
  8: fontSizes[9]
};
var bodySizes = {
  1: fontSizes[1],
  2: fontSizes[2]
};
var textSansSizes = {
  1: fontSizes[0],
  2: fontSizes[1],
  3: fontSizes[2],
  4: fontSizes[3],
  5: fontSizes[4],
  6: fontSizes[5],
  7: fontSizes[6],
  8: fontSizes[7],
  9: fontSizes[8],
  10: fontSizes[9]
};

Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);

// babel * typescript * rollup = ¯\_(ツ)_/¯

var minWidth = function minWidth(from) {
  return "@media (min-width: ".concat("".concat(from, "px"), ")");
};

var maxWidth = function maxWidth(until) {
  return "@media (max-width: ".concat("".concat(until - 1, "px"), ")");
};

var minWidthMaxWidth = function minWidthMaxWidth(from, until) {
  return "@media (min-width: ".concat("".concat(from, "px"), ") and (max-width: ", "".concat(until - 1, "px"), ")");
}; // e.g. from.*


var from = {
  mobileMedium: minWidth(breakpoints$1.mobileMedium),
  mobileLandscape: minWidth(breakpoints$1.mobileLandscape),
  phablet: minWidth(breakpoints$1.phablet),
  tablet: minWidth(breakpoints$1.tablet),
  desktop: minWidth(breakpoints$1.desktop),
  leftCol: minWidth(breakpoints$1.leftCol),
  wide: minWidth(breakpoints$1.wide) // e.g. until.*

};
var until = {
  mobileMedium: maxWidth(breakpoints$1.mobileMedium),
  mobileLandscape: maxWidth(breakpoints$1.mobileLandscape),
  phablet: maxWidth(breakpoints$1.phablet),
  tablet: maxWidth(breakpoints$1.tablet),
  desktop: maxWidth(breakpoints$1.desktop),
  leftCol: maxWidth(breakpoints$1.leftCol),
  wide: maxWidth(breakpoints$1.wide) // e.g. between.*.and.*

};
var between = {
  mobileMedium: {
    and: {
      mobileLandscape: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.mobileLandscape),
      phablet: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.phablet),
      tablet: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.mobileMedium, breakpoints$1.wide)
    }
  },
  mobileLandscape: {
    and: {
      phablet: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.phablet),
      tablet: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.mobileLandscape, breakpoints$1.wide)
    }
  },
  phablet: {
    and: {
      tablet: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.tablet),
      desktop: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.phablet, breakpoints$1.wide)
    }
  },
  tablet: {
    and: {
      desktop: minWidthMaxWidth(breakpoints$1.tablet, breakpoints$1.desktop),
      leftCol: minWidthMaxWidth(breakpoints$1.tablet, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.tablet, breakpoints$1.wide)
    }
  },
  desktop: {
    and: {
      leftCol: minWidthMaxWidth(breakpoints$1.desktop, breakpoints$1.leftCol),
      wide: minWidthMaxWidth(breakpoints$1.desktop, breakpoints$1.wide)
    }
  },
  leftCol: {
    and: {
      wide: minWidthMaxWidth(breakpoints$1.leftCol, breakpoints$1.wide)
    }
  }
};

exports.between = between;
exports.breakpoints = breakpoints$1;
exports.from = from;
exports.until = until;
